@@ -19,6 +19,7 @@ use std::{
     fmt,
     ops::{Deref, DerefMut},
 };
+use unicode_width::UnicodeWidthStr;
 
 mod cell;
 mod contacts;
@@ -299,91 +300,90 @@ impl CellBuffer {
     }
 
     fn get_style<MSG>(settings: &Settings, legend_css: String) -> Node<MSG> {
-        html::tags::style(
-            vec![],
-            vec![text(format!(
-                "line, path, circle,rect,polygon {{
-                          stroke: {stroke_color};
-                          stroke-width: {stroke_width};
-                          stroke-opacity: 1;
-                          fill-opacity: 1;
-                          stroke-linecap: round;
-                          stroke-linejoin: miter;
-                        }}
+        use sauron::html::units::px;
 
-                    text {{
-                        /* This fix the spacing bug in svg text*/
-                        white-space: pre;
-                        fill: {stroke_color};
-                        }}
-                        rect.backdrop{{
-                            stroke: none;
-                            fill: {background};
-                        }}
-                        .broken{{
-                            stroke-dasharray: 8;
-                        }}
-                        .filled{{
-                            fill: {fill_color};
-                        }}
-                        .bg_filled{{
-                            fill: {background};
-                        }}
-                        .nofill{{
-                            fill: {background};
-                        }}
+        let element_styles = sauron::jss!({
+                "line, path, circle,rect,polygon": {
+                      "stroke": settings.stroke_color,
+                      "stroke-width": settings.stroke_width,
+                      "stroke-opacity": 1,
+                      "fill-opacity": 1,
+                      "stroke-linecap": "round",
+                      "stroke-linejoin": "miter",
+                },
 
-                        text {{
-                         font-family: {font_family};
-                         font-size: {font_size}px;
-                        }}
+                "text": {
+                    /* This fix the spacing bug in svg text*/
+                    "white-space": "pre",
+                    "fill": settings.stroke_color,
+                },
 
-                        .end_marked_arrow{{
-                            marker-end: url(#arrow);
-                         }}
-                        .start_marked_arrow{{
-                            marker-start: url(#arrow);
-                         }}
+               "rect.backdrop":{
+                    "stroke": "none",
+                    "fill": settings.background,
+                },
 
-                        .end_marked_diamond{{
-                            marker-end: url(#diamond);
-                         }}
-                        .start_marked_diamond{{
-                            marker-start: url(#diamond);
-                         }}
+                ".broken":{
+                    "stroke-dasharray": 8,
+                },
 
-                        .end_marked_circle{{
-                            marker-end: url(#circle);
-                         }}
-                        .start_marked_circle{{
-                            marker-start: url(#circle);
-                         }}
+                ".filled":{
+                    "fill": settings.fill_color,
+                },
 
-                        .end_marked_open_circle{{
-                            marker-end: url(#open_circle);
-                         }}
-                        .start_marked_open_circle{{
-                            marker-start: url(#open_circle);
-                         }}
+                ".bg_filled":{
+                    "fill": settings.background,
+                },
 
-                        .end_marked_big_open_circle{{
-                            marker-end: url(#big_open_circle);
-                         }}
-                        .start_marked_big_open_circle{{
-                            marker-start: url(#big_open_circle);
-                         }}
+                ".nofill":{
+                    "fill": settings.background,
+                },
 
-                         {legend_css}
-                        ",
-                background = settings.background,
-                fill_color = settings.fill_color,
-                stroke_color = settings.stroke_color,
-                stroke_width = settings.stroke_width,
-                font_size = settings.font_size,
-                font_family = settings.font_family,
-                legend_css = legend_css,
-            ))],
-        )
+                "text": {
+                 "font-family": settings.font_family,
+                 "font-size": px(settings.font_size),
+                },
+
+                ".end_marked_arrow":{
+                    "marker-end": "url(#arrow)",
+                 },
+
+                ".start_marked_arrow":{
+                    "marker-start": "url(#arrow)",
+                 },
+
+                ".end_marked_diamond":{
+                    "marker-end": "url(#diamond)",
+                 },
+                ".start_marked_diamond":{
+                    "marker-start": "url(#diamond)",
+                 },
+
+                ".end_marked_circle":{
+                    "marker-end": "url(#circle)",
+                 },
+
+                ".start_marked_circle":{
+                    "marker-start": "url(#circle)",
+                 },
+
+                ".end_marked_open_circle":{
+                    "marker-end": "url(#open_circle)",
+                 },
+
+                ".start_marked_open_circle":{
+                    "marker-start": "url(#open_circle)",
+                 },
+
+                ".end_marked_big_open_circle":{
+                    "marker-end": "url(#big_open_circle)",
+                 },
+
+                ".start_marked_big_open_circle": {
+                    "marker-start": "url(#big_open_circle)",
+                 }
+        });
+        html::tags::style(vec![], vec![text(element_styles), text(legend_css)])
     }
 
     /// convert the fragments into svg nodes using the supplied settings, with size for the
@@ -539,16 +539,36 @@ impl CellBuffer {
             no_escaped_text = raw.to_string();
         } else {
             for (start, end) in char_locs.iter() {
-                let escaped = raw[*start + 1..*end].to_string();
+                let escaped = input_chars[*start + 1..*end].iter().fold(
+                    String::new(),
+                    |mut acc, c| {
+                        acc.push(*c);
+                        acc
+                    },
+                );
+                let escaped_unicode_width = escaped.width();
                 let cell = Cell::new(*start as i32, line as i32);
                 escaped_text.push((cell, escaped));
+                no_escaped_text += &input_chars[index..*start].iter().fold(
+                    String::new(),
+                    |mut acc, c| {
+                        acc.push(*c);
+                        acc
+                    },
+                );
 
-                no_escaped_text.push_str(&raw[index..*start]);
-                no_escaped_text.push_str(&" ".repeat(end + 1 - start));
+                // we add 2 to account for the double quotes on end of the escaped string
+                no_escaped_text += &" ".repeat(escaped_unicode_width + 2);
                 index = end + 1;
             }
-            // the rest of the text
-            no_escaped_text.push_str(&raw[index..raw.len()]);
+            // include the rest of the text
+            no_escaped_text += &input_chars[index..].iter().fold(
+                String::new(),
+                |mut acc, c| {
+                    acc.push(*c);
+                    acc
+                },
+            );
         }
         (escaped_text, no_escaped_text)
     }
@@ -651,6 +671,28 @@ mod tests {
         assert_eq!(ex2, unescaped);
     }
 
+    #[test]
+    fn test_issue38_escaped_german_umlauts() {
+        let raw = r#"This is some german character "ÖÄÜ" and was escaped"#;
+        let ex2 = r#"This is some german character       and was escaped"#;
+        let (escaped, unescaped) = CellBuffer::escape_line(0, raw);
+        println!("escaped: {:#?}", escaped);
+        println!("unescaped: {}", unescaped);
+        assert_eq!(vec![(Cell::new(30, 0), "ÖÄÜ".to_string())], escaped);
+        assert_eq!(ex2, unescaped);
+    }
+
+    #[test]
+    fn test_issue38_escape_cjk() {
+        let raw = r#"This is some CJK "一" and was escaped"#;
+        let ex2 = r#"This is some CJK      and was escaped"#;
+        let (escaped, unescaped) = CellBuffer::escape_line(0, raw);
+        println!("escaped: {:#?}", escaped);
+        println!("unescaped: {}", unescaped);
+        assert_eq!(vec![(Cell::new(17, 0), r#"一"#.to_string())], escaped);
+        assert_eq!(ex2, unescaped);
+    }
+
     #[test]
     fn test_simple_adjacents() {
         let art = r#"
